@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                   Copyright (C) 2007  QRW Software
+--                 Copyright (C) 2007-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -29,6 +29,13 @@
 -- This is a one time use program to add acronyms to the existing Credit Unions
 --
 -- $Log: add_acronyms.c,v $
+-- Revision 1.4  2008/09/01 00:22:49  jsedwards
+-- Fix year in copyright.  NO code changes.
+--
+-- Revision 1.3  2008/08/31 16:24:43  jsedwards
+-- Added assert around call to nwos_read_object_from_disk because now it
+-- returns false if it fails, before it asserted itself if it failed.
+--
 -- Revision 1.2  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -95,7 +102,7 @@ int main(int argc, char* argv[])
 
 	assert(nwos_find_public_credit_union(credit_unions[i].name, &cu_ref));
 
-	nwos_read_object_from_disk(&cu_ref, &cu_obj, sizeof(cu_obj));
+	assert(nwos_read_object_from_disk(&cu_ref, &cu_obj, sizeof(cu_obj)));
 
 	nwos_create_public_acronym(credit_unions[i].acronym, &acronym_ref);
 
