@@ -27,6 +27,20 @@
 --
 --
 -- $Log: check_objects.c,v $
+-- Revision 1.20  2008/09/01 03:13:40  jsedwards
+-- Change for new nwos_initialize_objectify calling convention (doesn't pass
+-- back root_object_reference anymore) and removed call to nwos_set_root_object
+-- because initialize calls it now.
+--
+-- Revision 1.19  2008/08/31 21:53:51  jsedwards
+-- Added an assert around calls to nwos_read_variable_sized_object_from_disk
+-- and nwos_read_object_from_disk because now they return false when they fail
+-- instead of asserting themselves.
+--
+-- Revision 1.18  2008/08/30 12:46:06  jsedwards
+-- Removed code and variables to read pass phrase and pass it to initialize,
+-- and change parameters passed to initialize.
+--
 -- Revision 1.17  2008/02/03 01:05:23  jsedwards
 -- Changed DEFAULT_TYPE_RO to READ_ONLY.
 --
@@ -160,7 +174,7 @@ void check_spelling(ObjRef* spelling_ref)
     printf("Spelling: %08x ", nwos_ref_to_word(spelling_ref));
     fflush(stdout);
 
-    nwos_read_variable_sized_object_from_disk(spelling_ref, kludge, sizeof(kludge), &get_spelling_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(spelling_ref, kludge, sizeof(kludge), &get_spelling_object_size));
 
     for (i = 0; i < spelling_obj_ptr->count; i++) buffer[i] = spelling_obj_ptr->storage[i];
     buffer[i] = '\0';
@@ -196,13 +210,13 @@ void check_name(ObjRef* name_ref)
     printf("Name: %08x\n", nwos_ref_to_word(name_ref));
     fflush(stdout);
 
-    nwos_read_variable_sized_object_from_disk(name_ref, kludge, sizeof(kludge), &get_name_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(name_ref, kludge, sizeof(kludge), &get_name_object_size));
 
     for (i = 0; i < name_obj_ptr->count; i++)
     {
 	printf("  %08x\n", nwos_ref_to_word(&name_obj_ptr->spelling[i]));
 
-	nwos_read_variable_sized_object_from_disk(&name_obj_ptr->spelling[i], cludge, sizeof(cludge), &get_spelling_object_size);
+	assert(nwos_read_variable_sized_object_from_disk(&name_obj_ptr->spelling[i], cludge, sizeof(cludge), &get_spelling_object_size));
 
 	if (!reference_list_has_reference(&spelling_obj_ptr->header.object.references, name_ref))
 	{
@@ -229,7 +243,7 @@ void check_month(ObjRef* month_ref)
 
     printf("Month: %08x\n", nwos_ref_to_word(month_ref));
 
-    nwos_read_object_from_disk(month_ref, &month_obj, sizeof(month_obj));
+    assert(nwos_read_object_from_disk(month_ref, &month_obj, sizeof(month_obj)));
 
     nwos_ordinal_number_to_string(&month_obj.number, number, sizeof(number));
 
@@ -268,7 +282,7 @@ void check_file_path(ObjRef* file_path_ref)
     printf("File Path: %08x ", nwos_ref_to_word(file_path_ref));
     fflush(stdout);
 
-    nwos_read_variable_sized_object_from_disk(file_path_ref, kludge, sizeof(kludge), &get_path_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(file_path_ref, kludge, sizeof(kludge), &get_path_object_size));
 
     for (i = 0; i < file_path_obj_ptr->count; i++) buffer[i] = file_path_obj_ptr->storage[i];
     buffer[i] = '\0';
@@ -289,7 +303,7 @@ void check_file_path(ObjRef* file_path_ref)
 
 	if (is_same_object(&object_class, &assoc_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &assoc_obj, sizeof(assoc_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &assoc_obj, sizeof(assoc_obj)));
 
 	    if (!is_same_object(file_path_ref, &assoc_obj.path))
 	    {
@@ -330,7 +344,7 @@ void check_class(ObjRef* class_ref)
 
     printf("Reading class definition: %08x\n", nwos_ref_to_word(class_ref));
 
-    nwos_read_variable_sized_object_from_disk(class_ref, kludge, sizeof(kludge), &nwos_get_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(class_ref, kludge, sizeof(kludge), &nwos_get_object_size));
 
     nwos_name_to_string(&class_def_obj_ptr->name, buffer, sizeof(buffer));
 
@@ -389,30 +403,15 @@ int main(int argc, char* argv[])
     char buffer[64];
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*) kludge;
-    ObjRef root_object_ref;
-    uint8 big_key[16 + 8 + 4];
-    uint8 bf_key[16];
-    uint32 linear;
-    uint32 serial;
     ReferenceList* ref_list;
     int num_refs;
 
-    nwos_get_key_from_password(big_key, sizeof(big_key));
 
-    memcpy(bf_key, big_key, 16);
-    linear = ((uint32)big_key[16] << 24) | ((uint32)big_key[17] << 16) | ((uint32)big_key[18] << 8) | (uint32)big_key[19];
-    memcpy(root_object_ref.id, big_key+20, 4);
-    serial = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
-
-    nwos_initialize_objectify(bf_key, linear, serial, READ_ONLY, DEFAULT_FILE);
-
-    printf("Setting root object: %08x\n", nwos_ref_to_word(&root_object_ref));
-
-    nwos_set_root_object(&root_object_ref);
+    nwos_initialize_objectify(READ_ONLY, DEFAULT_FILE);
 
     printf("Reading class definition class: %08x\n", nwos_ref_to_word(&nwos_private_class_definition_class_ref));
 
-    nwos_read_variable_sized_object_from_disk(&nwos_private_class_definition_class_ref, kludge, sizeof(kludge), &nwos_get_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(&nwos_private_class_definition_class_ref, kludge, sizeof(kludge), &nwos_get_object_size));
 
     nwos_name_to_string(&class_def_obj_ptr->name, buffer, sizeof(buffer));
 
