@@ -27,6 +27,11 @@
 --
 --
 -- $Log: class_definition.c,v $
+-- Revision 1.29  2008/08/31 21:53:51  jsedwards
+-- Added an assert around calls to nwos_read_variable_sized_object_from_disk
+-- and nwos_read_object_from_disk because now they return false when they fail
+-- instead of asserting themselves.
+--
 -- Revision 1.28  2008/07/19 13:07:03  jsedwards
 -- Added asserts to verify that after an updated class is cloned that it can
 -- be accessed succesfully.  NO changes to the code operation.
@@ -188,7 +193,7 @@ static size_t feature_size(ObjRef* class_ref)
     {
 	copy_reference(&dictionary[i].class, class_ref);
 
-	nwos_read_variable_sized_object_from_disk(class_ref, kludge, sizeof(kludge), &get_class_object_size);
+	assert(nwos_read_variable_sized_object_from_disk(class_ref, kludge, sizeof(kludge), &get_class_object_size));
 	nwos_name_to_string(&class_def_obj_ptr->name, name, sizeof(name));
 
 	if (strcmp(name, "Object Reference") == 0)
@@ -239,11 +244,11 @@ size_t nwos_get_object_size(void* object)
 
     no_more_calls = true;
 
-    nwos_read_variable_sized_object_from_disk(&header->common.class_definition, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(&header->common.class_definition, kludge, sizeof(kludge), &get_class_object_size));
 
     for (i = 0; i < class_def_obj_ptr->count; i++)
     {
-	nwos_read_object_from_disk(&class_def_obj_ptr->feature[i], &feature_obj, sizeof(feature_obj));
+	assert(nwos_read_object_from_disk(&class_def_obj_ptr->feature[i], &feature_obj, sizeof(feature_obj)));
 
 	size = feature_size(&feature_obj.class);
 
@@ -306,7 +311,7 @@ void nwos_clone_updated_class_definition(ObjRef* old_private_ref, ObjRef* clone_
 
     nwos_generate_new_completely_random_id(clone_ref);
 
-    nwos_read_variable_sized_object_from_disk(old_private_ref, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(old_private_ref, kludge, sizeof(kludge), &get_class_object_size));
 
     copy_reference(&class_def_obj_ptr->header.object.next_version, clone_ref);
 
@@ -315,14 +320,14 @@ void nwos_clone_updated_class_definition(ObjRef* old_private_ref, ObjRef* clone_
     nwos_overwrite_object_to_disk(old_private_ref, class_def_obj_ptr, get_class_object_size(class_def_obj_ptr));
 
     /* get the old public object */
-    nwos_read_variable_sized_object_from_disk(&class_def_obj_ptr->header.object.clone_of, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(&class_def_obj_ptr->header.object.clone_of, kludge, sizeof(kludge), &get_class_object_size));
 
     assert(!is_void_reference(&class_def_obj_ptr->header.object.next_version));
 
     while (!is_void_reference(&class_def_obj_ptr->header.object.next_version))
     {
 	copy_reference(&public_ref, &class_def_obj_ptr->header.object.next_version);
-	nwos_read_variable_sized_object_from_disk(&public_ref, kludge, sizeof(kludge), &get_class_object_size);
+	assert(nwos_read_variable_sized_object_from_disk(&public_ref, kludge, sizeof(kludge), &get_class_object_size));
     }
 
     snprintf(msg, sizeof(msg), "clone_class_definition(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
@@ -413,7 +418,7 @@ void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref)
 
     memset(kludge, 0, sizeof(kludge));
 
-    nwos_read_variable_sized_object_from_disk(class_to_clone_ref, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(class_to_clone_ref, kludge, sizeof(kludge), &get_class_object_size));
 
     nwos_generate_new_completely_random_id(clone_ref);
 
@@ -458,7 +463,7 @@ bool nwos_find_public_class_definition(char* name, ObjRef* class_ref)
 
     memset(kludge, 0, sizeof(kludge));
 
-    nwos_read_variable_sized_object_from_disk(&nwos_public_class_definition_class_ref, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(&nwos_public_class_definition_class_ref, kludge, sizeof(kludge), &get_class_object_size));
 
     ref_list = nwos_malloc_reference_list(&class_def_obj_ptr->header.object.references);
 
@@ -472,7 +477,7 @@ bool nwos_find_public_class_definition(char* name, ObjRef* class_ref)
 
 	if (is_same_object(&object_class, &nwos_public_class_definition_class_ref))   /* it is a class definition object */
 	{
-	    nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_class_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_class_object_size));
 
 	    if (is_void_reference(&class_def_obj_ptr->header.object.next_version))
 	    {
@@ -508,7 +513,7 @@ bool nwos_find_private_class_definition(char* name, ObjRef* class_ref)
 
     memset(kludge, 0, sizeof(kludge));
 
-    nwos_read_variable_sized_object_from_disk(&nwos_private_class_definition_class_ref, kludge, sizeof(kludge), &get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(&nwos_private_class_definition_class_ref, kludge, sizeof(kludge), &get_class_object_size));
 
     ref_list = nwos_malloc_reference_list(&class_def_obj_ptr->header.object.references);
 
@@ -523,7 +528,7 @@ bool nwos_find_private_class_definition(char* name, ObjRef* class_ref)
 
 	if (is_same_object(&object_class, &nwos_private_class_definition_class_ref))   /* it is a class definition object */
 	{
-	    nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_class_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_class_object_size));
 
 	    if (is_void_reference(&class_def_obj_ptr->header.object.next_version))
 	    {
@@ -566,7 +571,7 @@ void nwos_read_class_definition(ObjRef* ref, C_struct_Class_Definition* class_de
     uint8 kludge[FILE_BLOCK_SIZE];
     assert(!is_void_reference(ref));
 
-    nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), get_class_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), get_class_object_size));
 
     /* Holy shit Batman this is a mess! */
     /* memcpy(class_def, kludge, get_class_object_size(kludge)); */
@@ -602,7 +607,7 @@ bool nwos_find_public_feature_definition(ObjRef* type_ref, char* label, int coun
 
 	assert(nwos_find_public_class_definition("FEATURE DEFINITION", &feature_class_ref));
 
-	nwos_read_variable_sized_object_from_disk(&label_ref, kludge, sizeof(kludge), &get_name_object_size);
+	assert(nwos_read_variable_sized_object_from_disk(&label_ref, kludge, sizeof(kludge), &get_name_object_size));
 	ref_list = nwos_malloc_reference_list(&ptr_name_obj->header.object.references);
 
 	num_refs = ref_list->common_header.num_refs;
@@ -613,7 +618,7 @@ bool nwos_find_public_feature_definition(ObjRef* type_ref, char* label, int coun
 
 	    if (is_same_object(&feature_class_ref, &object_class))
 	    {
-		nwos_read_object_from_disk(&ref_list->references[i], &feature_obj, sizeof(feature_obj));
+		assert(nwos_read_object_from_disk(&ref_list->references[i], &feature_obj, sizeof(feature_obj)));
 
 		assert(is_same_object(&feature_obj.label, &label_ref));
 
