@@ -27,6 +27,15 @@
 --
 --
 -- $Log: computer.c,v $
+-- Revision 1.34  2008/09/01 03:13:41  jsedwards
+-- Change for new nwos_initialize_objectify calling convention (doesn't pass
+-- back root_object_reference anymore) and removed call to nwos_set_root_object
+-- because initialize calls it now.
+--
+-- Revision 1.33  2008/08/30 12:46:07  jsedwards
+-- Removed code and variables to read pass phrase and pass it to initialize,
+-- and change parameters passed to initialize.
+--
 -- Revision 1.32  2008/02/03 01:00:16  jsedwards
 -- Changed DEFAULT_TYPE_RW to READ_WRITE.
 --
@@ -401,26 +410,12 @@ void execute_command(char *command)
 
 int main(int argc, char* argv[])
 {
-    ObjRef root_object_ref;
-    uint8 big_key[16 + 8 + 4];
-    uint8 bf_key[16];
-    uint32 linear;
-    uint32 serial;
     char command[80];
     int i;
 
     printf("\n");
 
-    nwos_get_key_from_password(big_key, sizeof(big_key));
-
-    memcpy(bf_key, big_key, 16);
-    linear = ((uint32)big_key[16] << 24) | ((uint32)big_key[17] << 16) | ((uint32)big_key[18] << 8) | (uint32)big_key[19];
-    memcpy(root_object_ref.id, big_key+20, 4);
-    serial = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
-
-    nwos_initialize_objectify(bf_key, linear, serial, READ_WRITE, DEFAULT_FILE);
-
-    nwos_set_root_object(&root_object_ref);
+    nwos_initialize_objectify(READ_WRITE, DEFAULT_FILE);
 
     nwos_set_security_level(Security_Extreme);
 
