@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
+--                 Copyright (C) 2005-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,13 @@
 --
 --
 -- $Log: date.c,v $
+-- Revision 1.40  2008/09/01 00:10:49  jsedwards
+-- Fix copyright year.  NO code changes.
+--
+-- Revision 1.39  2008/08/31 20:33:17  jsedwards
+-- Add assert around calls to nwos_read_object_from_disk because it now
+-- returns false when it fails, whereas before it would assert itself.
+--
 -- Revision 1.38  2007/07/01 19:44:11  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -214,7 +221,7 @@ static bool find_year_from_cardinal(ObjRef* year_class_ref, ObjRef* cardinal_ref
 
 	if (is_same_object(&class_ref, year_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &year_obj, sizeof(year_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &year_obj, sizeof(year_obj)));
 
 	    if (is_same_object(&year_obj.number, cardinal_ref))   /* found a match */
 	    {
@@ -356,7 +363,7 @@ void nwos_find_or_create_private_year(uint16 year, ObjRef* ref)
 
 	nwos_find_or_create_private_class_definition("YEAR", &private_year_class_ref);
 
-	nwos_read_object_from_disk(&public_year_ref, &year_obj, sizeof(year_obj));
+	assert(nwos_read_object_from_disk(&public_year_ref, &year_obj, sizeof(year_obj)));
 
 	nwos_generate_new_completely_random_id(ref);
 
@@ -421,7 +428,7 @@ static bool find_month(ObjRef* month_class_ref, uint8 month, ObjRef* ref)
 
 	if (is_same_object(&class_ref, month_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &month_obj, sizeof(month_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &month_obj, sizeof(month_obj)));
 
 	    if (is_same_object(&month_obj.number, &ordinal_ref))   /* found a match */
 	    {
@@ -488,7 +495,7 @@ void nwos_find_or_create_private_month(uint8 month, ObjRef* ref)
 
 	nwos_find_or_create_private_class_definition("MONTH", &private_month_class_ref);
 
-	nwos_read_object_from_disk(&public_month_ref, &month_obj, sizeof(month_obj));
+	assert(nwos_read_object_from_disk(&public_month_ref, &month_obj, sizeof(month_obj)));
 
 	nwos_generate_new_completely_random_id(ref);
 
@@ -551,7 +558,7 @@ static bool find_month_and_day(ObjRef* month_and_day_class_ref, ObjRef* month_re
 
 	if (is_same_object(&class_ref, month_and_day_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &month_and_day_obj, sizeof(month_and_day_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &month_and_day_obj, sizeof(month_and_day_obj)));
 
 	    if (is_same_object(&month_and_day_obj.day, &ordinal_ref))   /* found a match */
 	    {
@@ -628,7 +635,7 @@ void nwos_find_or_create_private_month_and_day(uint8 month, uint8 day, ObjRef* r
 
 	nwos_find_or_create_private_month(month, &private_month_ref);
 
-	nwos_read_object_from_disk(&public_month_and_day_ref, &month_and_day_obj, sizeof(month_and_day_obj));
+	assert(nwos_read_object_from_disk(&public_month_and_day_ref, &month_and_day_obj, sizeof(month_and_day_obj)));
 
 	nwos_generate_new_completely_random_id(ref);
 
@@ -693,7 +700,7 @@ static bool find_date(ObjRef* date_class_ref, ObjRef* year_ref, ObjRef* month_an
 
 	if (is_same_object(&object_class, date_class_ref))   /* it is a date object */
 	{
-	    nwos_read_object_from_disk(&year_ref_list->references[i], &date_obj, sizeof(date_obj));
+	    assert(nwos_read_object_from_disk(&year_ref_list->references[i], &date_obj, sizeof(date_obj)));
 
 	    if (is_same_object(&date_obj.month_and_day, month_and_day_ref))
 	    {
@@ -830,7 +837,7 @@ bool nwos_year_to_string(ObjRef* ref, char* string, size_t size)
 
     assert(size >= 5);
 
-    nwos_read_object_from_disk(ref, &year_obj, sizeof(year_obj));
+    assert(nwos_read_object_from_disk(ref, &year_obj, sizeof(year_obj)));
 
     nwos_cardinal_number_to_string(&year_obj.number, string, size);
 
@@ -844,7 +851,7 @@ bool nwos_month_number_to_string(ObjRef* ref, char* string, size_t size)
 
     assert(size >= 3);
 
-    nwos_read_object_from_disk(ref, &month_obj, sizeof(month_obj));
+    assert(nwos_read_object_from_disk(ref, &month_obj, sizeof(month_obj)));
 
     nwos_ordinal_number_to_string(&month_obj.number, string, size);
 
@@ -857,8 +864,8 @@ bool nwos_date_to_string(ObjRef* ref, char* string, size_t size)
     C_struct_Date date_obj;
     C_struct_Month_And_Day month_and_day_obj;
 
-    nwos_read_object_from_disk(ref, &date_obj, sizeof(date_obj));
-    nwos_read_object_from_disk(&date_obj.month_and_day, &month_and_day_obj, sizeof(month_and_day_obj));
+    assert(nwos_read_object_from_disk(ref, &date_obj, sizeof(date_obj)));
+    assert(nwos_read_object_from_disk(&date_obj.month_and_day, &month_and_day_obj, sizeof(month_and_day_obj)));
 
     assert(size >= 11);
 
