@@ -27,6 +27,24 @@
 --
 --
 -- $Log: disk_usage.c,v $
+-- Revision 1.27.2.1  2008/12/21 04:12:47  jsedwards
+-- Merged in main truck to get bug fixes for graph.
+--
+-- Revision 1.31  2008/12/05 13:00:09  jsedwards
+-- Fix Bug #2392474 - overflow in graph calculation.  (Note: this was fixed
+-- inadvertantly by the previous change to display gigabytes instead of 100%,
+-- but decided to fix the overflow anyway, just in case.)
+--
+-- Revision 1.30  2008/11/28 16:57:46  jsedwards
+-- Changed to display graph in gigabytes instead of percent.
+--
+-- Revision 1.29  2008/11/28 16:17:57  jsedwards
+-- Added printing of allocated space in graph with a '+'.
+--
+-- Revision 1.28  2008/11/28 15:27:08  jsedwards
+-- Fix Bug #2354269 - was only using allocated blocks for divisor instead of
+-- all possible blocks in the chunks.
+--
 -- Revision 1.27  2008/10/20 02:20:24  jsedwards
 -- Fix Bug #2117258 - Seg fault running disk_usage.  Changed for loop to only
 -- do used_private_chunks instead of total_private_chunks because only space
@@ -283,43 +301,52 @@ void display_graph(Chunk_Info chunk_info[], uint32 num_chunks)
     const int graph_bits = 6;
     const int divisor = 1 << (graph_bits - 4);
     uint32 used_blocks[1 << graph_bits];
+    uint32 alloc_blocks[1 << graph_bits];
     uint32 total_blocks[1 << graph_bits];
+    uint32 chunk;
     int segment;
-    int percent;
+    int gigabytes;
     
     int i;
 
+
     memset(used_blocks, 0, sizeof(used_blocks));
+    memset(alloc_blocks, 0, sizeof(alloc_blocks));
     memset(total_blocks, 0, sizeof(total_blocks));
 
+    for (chunk = MINIMUM_PRIVATE_REFERENCE; chunk < MAXIMUM_PRIVATE_REFERENCE; chunk += USABLE_BLOCKS_PER_CHUNK)
+    {
+	segment = chunk >> (32 - graph_bits);
+
+	assert((RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)) <= segment && segment < (1 << graph_bits));
+
+	total_blocks[segment] += USABLE_BLOCKS_PER_CHUNK;
+    }
+
     for (i = 0; i < num_chunks; i++)
     {
 	segment = chunk_info[i].ref >> (32 - graph_bits);
 
 	assert((RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)) <= segment && segment < (1 << graph_bits));
 
-	total_blocks[segment] += USABLE_BLOCKS_PER_CHUNK;
-
 	used_blocks[segment] += chunk_info[i].used;
+	alloc_blocks[segment] += USABLE_BLOCKS_PER_CHUNK;
     }
 
-    for (percent = 100; percent >= 0; percent -= 5)
+    for (gigabytes = (1024 / (1 << graph_bits)); gigabytes >= 0; gigabytes--)
     {
-	if (percent % 10 == 0)
-	{
-	    printf("%3d |", percent);
-	}
-	else
-	{
-	    printf("    |");
-	}
+	printf(" %2d GB |", gigabytes);
 
 	for (i = (RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)); i < (1 << graph_bits); i++)
 	{
-	    if (total_blocks[i] > 0 && ((used_blocks[i] * 100) / total_blocks[i]) >= (uint32)percent)
+	    if (used_blocks[i] > 0 && (((uint64)used_blocks[i] * (1024 / (1 << graph_bits))) / total_blocks[i]) >= (uint64)gigabytes)
 	    {
 		putchar('*');
 	    }
+	    else if (alloc_blocks[i] > 0 && (((uint64)alloc_blocks[i] * (1024 / (1 << graph_bits))) / total_blocks[i]) >= (uint64)gigabytes)
+	    {
+		putchar('+');
+	    }
 	    else
 	    {
 		putchar(' ');
@@ -329,11 +356,11 @@ void display_graph(Chunk_Info chunk_info[], uint32 num_chunks)
 	putchar('\n');
     }
 
-    printf("    +");
+    printf("       +");
     for (i = (RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)); i < (1 << graph_bits); i++) putchar('-');
     putchar('\n');
 
-    printf("     ");
+    printf("        ");
     for (i = (RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)); i < (1 << graph_bits); i++)
     {
 	if (i % divisor == 0)
@@ -353,6 +380,10 @@ void display_graph(Chunk_Info chunk_info[], uint32 num_chunks)
 	}
     }
     putchar('\n');
+    putchar('\n');
+
+    printf("     * = used\n");
+    printf("     + = allocated, but unused\n");
 }
 
 
