@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                   Copyright (C) 2007  QRW Software
+--                 Copyright (C) 2007-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,14 @@
 --
 --
 -- $Log: financial.c,v $
+-- Revision 1.7  2008/09/01 00:10:51  jsedwards
+-- Fix copyright year.  NO code changes.
+--
+-- Revision 1.6  2008/08/31 21:53:52  jsedwards
+-- Added an assert around calls to nwos_read_variable_sized_object_from_disk
+-- and nwos_read_object_from_disk because now they return false when they fail
+-- instead of asserting themselves.
+--
 -- Revision 1.5  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -140,7 +148,7 @@ bool nwos_find_public_credit_union(char* name, ObjRef* ref)
 
 	    if (is_same_object(&object_class, &cu_class_ref))   /* it is a word object */
 	    {
-		nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj));
+		assert(nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj)));
 
 		memcpy(ref, &ref_list->references[i], sizeof(ObjRef));
 		result = true;
@@ -185,7 +193,7 @@ void nwos_list_public_credit_unions()
 
 	if (is_same_object(&object_class, &cu_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj)));
 
 	    if (!is_void_reference(&cu_obj.short_name))
 	    {
@@ -259,7 +267,7 @@ bool nwos_find_private_credit_union(char* name, ObjRef* ref)
 
 	    if (is_same_object(&object_class, &private_class_ref))
 	    {
-		nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj));
+		assert(nwos_read_object_from_disk(&ref_list->references[i], &cu_obj, sizeof(cu_obj)));
 
 		if (is_same_object(&cu_obj.header.object.clone_of, &public_ref))   /* found a match */
 		{
@@ -296,7 +304,7 @@ ObjCreateResult nwos_find_or_create_private_credit_union(char* name, ObjRef* ref
     {
 	nwos_find_or_create_private_class_definition("CREDIT UNION", &private_class_ref);
 
-	nwos_read_object_from_disk(&public_cu_ref, &cu_obj, sizeof(cu_obj));
+	assert(nwos_read_object_from_disk(&public_cu_ref, &cu_obj, sizeof(cu_obj)));
 
 	nwos_generate_new_completely_random_id(ref);
 
@@ -362,7 +370,7 @@ bool nwos_find_account_number(char* number, ObjRef* ref)
 
 	    if (is_same_object(&object_class, &number_class_ref))
 	    {
-		nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_account_number_object_size);
+		assert(nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_account_number_object_size));
 
 		/* remember ptr_number_obj points to the kludge buffer */
 
@@ -421,11 +429,11 @@ ObjCreateResult nwos_find_or_create_account_number(char* number, ObjRef* ref)
 	nwos_add_to_references(ref, &number_class_ref);
 
 	ptr_number_obj = malloc(sizeof(C_struct_Account_Number) + length);
-	nwos_read_object_from_disk(ref, ptr_number_obj, sizeof(C_struct_Account_Number) + length);
+	assert(nwos_read_object_from_disk(ref, ptr_number_obj, sizeof(C_struct_Account_Number) + length));
 	assert(memcmp(kludge, ptr_number_obj, sizeof(C_struct_Account_Number) + length) == 0);
 
 	memset(kludge, 0, sizeof(kludge));  /* clear it */
-	nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_account_number_object_size);  /* read the other way */
+	assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_account_number_object_size));  /* read the other way */
 	assert(memcmp(ptr_number_obj, kludge, sizeof(C_struct_Account_Number) + length) == 0);
 
 	free(ptr_number_obj);
@@ -443,7 +451,7 @@ void nwos_account_number_to_string(ObjRef* ref, char* string, size_t size)
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_Account_Number* ptr_number_obj = (C_struct_Account_Number*)kludge;
 
-    nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_account_number_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_account_number_object_size));
 
     assert(ptr_number_obj->count < size);
 
@@ -481,7 +489,7 @@ bool nwos_find_account(ObjRef* credit_union_ref, ObjRef* account_num_ref, ObjRef
 
 	    if (is_same_object(&object_class, &account_class_ref))
 	    {
-		nwos_read_object_from_disk(&ref_list->references[i], &account_obj, sizeof(account_obj));
+		assert(nwos_read_object_from_disk(&ref_list->references[i], &account_obj, sizeof(account_obj)));
 
 		if (is_same_object(&account_obj.institution, credit_union_ref)
 		    && is_same_object(&account_obj.number, account_num_ref))   /* found a match */
@@ -533,7 +541,7 @@ void nwos_create_account(ObjRef* credit_union_ref, ObjRef* account_num_ref, ObjR
     nwos_add_to_references(ref, &account_obj.institution);
     nwos_add_to_references(ref, &account_obj.number);
 
-    nwos_read_object_from_disk(ref, &test_obj, sizeof(C_struct_Account));
+    assert(nwos_read_object_from_disk(ref, &test_obj, sizeof(C_struct_Account)));
     assert(memcmp(&account_obj, &test_obj, sizeof(C_struct_Account)) == 0);
 }
 
@@ -578,11 +586,11 @@ void nwos_create_checking(ObjRef* account_ref, char* id, ObjRef* ref)
     nwos_add_to_references(ref, &ptr_checking_obj->account);
 
     ptr_checking_obj = malloc(sizeof(C_struct_Checking) + length);
-    nwos_read_object_from_disk(ref, ptr_checking_obj, sizeof(C_struct_Checking) + length);
+    assert(nwos_read_object_from_disk(ref, ptr_checking_obj, sizeof(C_struct_Checking) + length));
     assert(memcmp(kludge, ptr_checking_obj, sizeof(C_struct_Checking) + length) == 0);
 
     memset(kludge, 0, sizeof(kludge));  /* clear it */
-    nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_checking_object_size);  /* read the other way */
+    assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_checking_object_size));  /* read the other way */
     assert(memcmp(ptr_checking_obj, kludge, sizeof(C_struct_Checking) + length) == 0);
 
     free(ptr_checking_obj);
@@ -727,11 +735,11 @@ void nwos_list_accounts()
 
 	    if (is_same_object(&object_class, &checking_class_ref))
 	    {
-		nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_checking_object_size);
+		assert(nwos_read_variable_sized_object_from_disk(&ref_list->references[i], kludge, sizeof(kludge), &get_checking_object_size));
 
-		nwos_read_object_from_disk(&ptr_checking_obj->account, &account_obj, sizeof(account_obj));
+		assert(nwos_read_object_from_disk(&ptr_checking_obj->account, &account_obj, sizeof(account_obj)));
 
-		nwos_read_object_from_disk(&account_obj.institution, &cu_obj, sizeof(cu_obj));
+		assert(nwos_read_object_from_disk(&account_obj.institution, &cu_obj, sizeof(cu_obj)));
 
 		nwos_account_number_to_string(&account_obj.number, number, sizeof(number));
 
@@ -782,7 +790,7 @@ void nwos_list_credit_unions()
 
 	if (is_same_object(&object_class, &person_class_ref))
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &person_obj, sizeof(person_obj));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &person_obj, sizeof(person_obj)));
 
 	    nwos_name_to_string(&person_obj.last_name, name, sizeof(name));
 
@@ -820,7 +828,7 @@ void nwos_describe_person(char* name)
     }
     else
     {
-	nwos_read_object_from_disk(&person_ref, &person_obj, sizeof(person_obj));
+	assert(nwos_read_object_from_disk(&person_ref, &person_obj, sizeof(person_obj)));
 
 	printf("full name: ");
 
