@@ -27,6 +27,14 @@
 --
 --
 -- $Log: import_file.c,v $
+-- Revision 1.40.2.2  2008/12/19 14:47:20  jsedwards
+-- Changed so that any PATH_NOT_FOUND, DUPLICATE_PATH, DUPLICATE_FILE, and
+-- MULTIPLE_FILES errors also exit with a 1 code.
+--
+-- Revision 1.40.2.1  2008/12/16 14:44:18  jsedwards
+-- Changed so that exit code is non-zero if any errors occurred during import
+-- or the archive was too full to import any files.
+--
 -- Revision 1.40  2008/09/01 18:53:48  jsedwards
 -- Fixed Bug #2043130 - asserts if given an absolute path.
 --
@@ -616,7 +624,12 @@ int main(int argc, char* argv[])
 
     nwos_terminate_objectify();
 
-    return 0;
+    return (result_counts[PATH_NOT_FOUND] |
+	    result_counts[DUPLICATE_PATH] |
+	    result_counts[DUPLICATE_FILE] |
+	    result_counts[MULTIPLE_FILES] |
+	    result_counts[ERROR_OCCURRED] |
+	    result_counts[NUM_OBJ_RESULTS]) != 0;
 }
 
 
