@@ -27,6 +27,10 @@
 --
 --
 -- $Log: list_files.c,v $
+-- Revision 1.35.2.1  2008/12/20 16:07:59  jsedwards
+-- Fixed to report arguments that didn't match any files and return exit code
+-- of 1 if any didn't.
+--
 -- Revision 1.35  2008/09/01 03:13:43  jsedwards
 -- Change for new nwos_initialize_objectify calling convention (doesn't pass
 -- back root_object_reference anymore) and removed call to nwos_set_root_object
@@ -320,10 +324,17 @@ int main(int argc, char* argv[])
     bool do_revision = false;
     bool do_public = false;
     bool match;
+    uint8 *arg_matches;
+    size_t matches_size;
+    int result = 0;          /* no errors result */
 
 
     nwos_log_arguments(0, NULL);   /* disable logging */
 
+    matches_size = argc + 7 / 8;   /* one bit for each argument */
+    arg_matches = nwos_malloc(matches_size);
+    memset(arg_matches, 0, matches_size);
+
     char* path = DEFAULT_FILE;
 
     argn = 1;
@@ -464,6 +475,7 @@ int main(int argc, char* argv[])
 			if (fnmatch(argv[j], name, 0) == 0)   /* found a match */
 			{
 			    match = true;
+			    arg_matches[j/8] |= 1 << (j & 7);
 			    break;
 			}
 		    }
@@ -595,6 +607,15 @@ int main(int argc, char* argv[])
     printf("Number of files: %d\n", num_files);
     fflush(stdout);
 
+    for (j = argn; j < argc; j++)
+    {
+	if ((arg_matches[j/8] & (1 << (j & 7))) == 0)
+	{
+	    fprintf(stderr, "No files found matching: %s\n", argv[j]);
+	    result = 1;
+	}
+    }
+
     if (old_file_revisions > 0)
     {
 	fprintf(stderr, "\n");
@@ -632,7 +653,7 @@ int main(int argc, char* argv[])
 
     nwos_terminate_objectify();
 
-    return 0;
+    return result;
 }
 
 
