@@ -27,6 +27,10 @@
 --
 --
 -- $Log: name.c,v $
+-- Revision 1.35  2008/08/31 21:26:16  jsedwards
+-- Added assert around calls to nwos_read_variable_sized_object_from_disk
+-- because it now returns false when it fails instead of asserting itself.
+--
 -- Revision 1.34  2008/04/26 11:42:18  jsedwards
 -- Added 'const' to char* name parameter in some of the functions.
 --
@@ -424,7 +428,7 @@ bool nwos_find_public_name(const char* name, ObjRef* ref)
 
 	for (j = 0; j < num_spellings[0]; j++)
 	{
-	    nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size));
 
 	    /* remember ptr_name_obj points to the kludge buffer */
 
@@ -631,7 +635,7 @@ bool nwos_find_private_name(const char* name, ObjRef* ref)
 
 	for (j = 0; j < num_spellings[0]; j++)
 	{
-	    nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size));
 
 	    /* remember ptr_name_obj points to the kludge buffer */
 
@@ -860,7 +864,7 @@ ObjCreateResult nwos_create_name(const char* name, ObjRef* ref)
 #ifdef DEBUG_NAME
 	    printf("reading spelling_ref_list[0]->references[%d]: %08lx\n", j, nwos_ref_to_word(&spelling_ref_list[0]->references[j]));
 #endif
-	    nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&spelling_ref_list[0]->references[j], kludge, sizeof(kludge), &get_name_object_size));
 
 	    /* remember ptr_name_obj points to the kludge buffer */
 
@@ -957,7 +961,7 @@ bool nwos_name_to_string(ObjRef* ref, char* string, size_t size)
     size_t name_obj_size;
 
     /* read the name object into the kludge buffer and then after we know what size it is malloc space and copy it there */
-    nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_name_object_size);
+    assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_name_object_size));
     ptr_name_obj = (C_struct_Name*)kludge;
     name_obj_size = sizeof(C_struct_Name) + (ptr_name_obj->count * sizeof(ObjRef));
     /* printf("name_obj_size: %d\n", name_obj_size); */
@@ -971,7 +975,7 @@ bool nwos_name_to_string(ObjRef* ref, char* string, size_t size)
     for (word = 0; word < ptr_name_obj->count; word++)
     {
 	assert(!is_void_reference(&ptr_name_obj->spelling[word]));
-	nwos_read_variable_sized_object_from_disk(&ptr_name_obj->spelling[word], kludge, sizeof(kludge), &get_spelling_object_size);
+	assert(nwos_read_variable_sized_object_from_disk(&ptr_name_obj->spelling[word], kludge, sizeof(kludge), &get_spelling_object_size));
 
 	string[i++] = toupper(ptr_spelling_obj->storage[0]);    /* first letter is upper case */
 
