@@ -27,6 +27,14 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.153  2008/10/31 13:03:31  jsedwards
+-- Added Unknown_Reference and Temporary_Reference types to Reference_Type,
+-- added external declarations for nwos_is_public_reference,
+-- nwos_is_private_reference, and nwos_is_temporary_reference functions.
+--
+-- Revision 1.152  2008/09/16 13:06:49  jsedwards
+-- Added external declaration for new nwos_erase_progress_bar function.
+--
 -- Revision 1.151  2008/09/01 03:00:09  jsedwards
 -- Change nwos_initialize_objectify declaration so private_root_object_ref is
 -- no longer passed back and nwos_set_root_object returns success or failure.
@@ -918,7 +926,7 @@ static inline uint32 byteswap_uint32(uint32 x)
 }
 
 
-typedef enum { Public_Reference, Private_Reference } Reference_Type;
+typedef enum { Unknown_Reference, Public_Reference, Private_Reference, Temporary_Reference } Reference_Type;
 typedef enum { Security_None=0, Security_Minimal, Security_Very_Low, Security_Low, Security_Medium, Security_High, Security_Extreme } Security_Level;
 
 typedef enum { CREATED_NEW, IMPORTED_DATA, CREATED_NEW_REVISION, FOUND_EXISTING, ERROR_OCCURRED, DUPLICATE_PATH, DUPLICATE_FILE, PATH_NOT_FOUND, MULTIPLE_FILES, CREATED_NEW_PATH_FOR_EXISTING_FILE, NUM_OBJ_RESULTS } ObjCreateResult;
@@ -963,6 +971,9 @@ extern size_t nwos_reference_list_size(ObjRef* ref);
 extern ReferenceList* nwos_malloc_reference_list(ObjRef* ref);
 extern void nwos_free_reference_list(ReferenceList* ref_list);
 
+extern bool nwos_is_public_reference(ObjRef* ref);
+extern bool nwos_is_private_reference(ObjRef* ref);
+extern bool nwos_is_temporary_reference(ObjRef* ref);
 extern Reference_Type nwos_reference_type(ObjRef* ref);
 extern void nwos_get_object_class(ObjRef* obj, ObjRef* object_class);
 extern void nwos_get_object_class_without_update(ObjRef* obj, ObjRef* object_class);
@@ -1146,6 +1157,7 @@ extern void nwos_get_key_from_password(uint8 key[], size_t key_size);
 
 extern void nwos_start_progress_bar();
 extern void nwos_update_progress_bar(float percent);  /* 0.0 <= percent < 1.0 */
+extern void nwos_erase_progress_bar();
 extern void nwos_finish_progress_bar();
 
 
