@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
+--                 Copyright (C) 2005-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,14 @@
 --
 --
 -- $Log: recrypt.c,v $
+-- Revision 1.6  2008/09/01 00:10:54  jsedwards
+-- Fix copyright year.  NO code changes.
+--
+-- Revision 1.5  2008/08/31 21:53:53  jsedwards
+-- Added an assert around calls to nwos_read_variable_sized_object_from_disk
+-- and nwos_read_object_from_disk because now they return false when they fail
+-- instead of asserting themselves.
+--
 -- Revision 1.4  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -151,7 +159,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
     {
 	nwos_get_object_class(&ref_list->references[i], &object_class);   /* find out what kind of object it is */
 
-	nwos_read_object_from_disk(&object_class, &class_def_obj, sizeof(class_def_obj));
+	assert(nwos_read_object_from_disk(&object_class, &class_def_obj, sizeof(class_def_obj)));
 	
 	nwos_name_to_string(&class_def_obj.name, buffer, sizeof(buffer));   /* get it's name */
     
@@ -181,9 +189,9 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 
 		    objs_to_save[num_objs_to_save].size = class_tbl[j].size;
 
-		    nwos_read_object_from_disk(&objs_to_save[num_objs_to_save].ref,
+		    assert(nwos_read_object_from_disk(&objs_to_save[num_objs_to_save].ref,
 					       objs_to_save[num_objs_to_save].ptr,
-					       objs_to_save[num_objs_to_save].size);
+					       objs_to_save[num_objs_to_save].size));
 
 		    if (strcmp(buffer, "Word") == 0)
 		    {
@@ -201,7 +209,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 		{
 		    memcpy(&objs_to_save[num_objs_to_save].ref, &ref_list->references[i], 4);
 
-		    nwos_read_variable_sized_object_from_disk(&objs_to_save[num_objs_to_save].ref, kludge, class_tbl[j].func);
+		    assert(nwos_read_variable_sized_object_from_disk(&objs_to_save[num_objs_to_save].ref, kludge, class_tbl[j].func));
 
 		    /* remember ptr_name_obj points to the kludge buffer */
 
@@ -250,7 +258,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 #if 0
 	if (is_same_object(&object_class, &class_def_class_ref))   /* it is a class definition object */
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0]));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
 	    strncpy(buffer, (char*)&header.common.version, 4);
 
@@ -259,7 +267,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 
 	    printf("  name: %s\n", buffer);
 
-	    nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0]));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
 	    strncpy(buffer, (char*)&header.common.version, 4);
 
@@ -269,7 +277,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 	    nwos_name_to_string(&class_def_objs[i].name, buffer, sizeof(buffer));   /* get it's name */
 	    printf("  name: %s\n", buffer);
 
-	    nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0]));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
 	    strncpy(buffer, (char*)&header.common.version, 4);
 
@@ -377,7 +385,7 @@ int main(int argc, char* argv[])
 	   old_root_object_ref.id[2],
 	   old_root_object_ref.id[3]);
 
-    nwos_read_object_from_disk(&old_root_object_ref, &root_obj, sizeof(root_obj));
+    assert(nwos_read_object_from_disk(&old_root_object_ref, &root_obj, sizeof(root_obj)));
 
     memcpy(&objs_to_save[num_objs_to_save].ref, &old_root_object_ref, 4);
     objs_to_save[num_objs_to_save].ptr = &root_obj;
@@ -392,7 +400,7 @@ int main(int argc, char* argv[])
 
     memcpy(&class_def_class_ref, &root_obj.class_definition_class, 4);
 
-    nwos_read_object_from_disk(&class_def_class_ref, &class_def_class_obj, sizeof(class_def_class_obj));
+    assert(nwos_read_object_from_disk(&class_def_class_ref, &class_def_class_obj, sizeof(class_def_class_obj)));
 
     printf("class_def_class_references: %02x%02x%02x%02x\n", 
 	   class_def_class_obj.header.object.references.id[0],
@@ -418,7 +426,7 @@ int main(int argc, char* argv[])
 
 	if (is_same_object(&object_class, &class_def_class_ref))   /* it is a class definition object */
 	{
-	    nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0]));
+	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
 	    strncpy(buffer, (char*)&class_def_objs[i].header.common.version, 4);
 
@@ -457,7 +465,7 @@ int main(int argc, char* argv[])
     free(ref_list);
     ref_list = NULL;
 #if 0
-	nwos_read_object_from_disk(&ref_list->references[i], &old_month_obj, sizeof(old_month_obj));
+	assert(nwos_read_object_from_disk(&ref_list->references[i], &old_month_obj, sizeof(old_month_obj)));
 #endif
 
     nwos_get_key_from_password(big_key, sizeof(big_key));
