@@ -27,6 +27,14 @@
 --
 --
 -- $Log: verify_file.c,v $
+-- Revision 1.24.2.2  2008/12/17 03:38:16  jsedwards
+-- Changed to keep track if any files weren't found or and weren't removed
+-- because there was no known backup and return an exit code of 1 if so.
+--
+-- Revision 1.24.2.1  2008/12/16 10:25:12  jsedwards
+-- Changed so that instead of asserting when a file doesn't match exactly, it
+-- prints a warning message.  (Part of fixing Bug #2427250.)
+--
 -- Revision 1.24  2008/09/01 18:53:48  jsedwards
 -- Fixed Bug #2043130 - asserts if given an absolute path.
 --
@@ -255,11 +263,12 @@ void shred(const char* path)
 
 typedef enum { Do_Not_Remove, Just_Remove, Shred_Before_Remove } Remove_Option;
 
-void process_file(const char* path, MatchCode match, Remove_Option remove_option)
+bool process_file(const char* path, MatchCode match, Remove_Option remove_option)
 {
     ObjRef ref;
     struct stat stat_struct;
     const char* invalid_type;
+    bool result = true;
 
     printf("%s: ", path);
     fflush(stdout);
@@ -286,21 +295,26 @@ void process_file(const char* path, MatchCode match, Remove_Option remove_option
 	{
 	    if (nwos_file_is_stored(&ref))
 	    {
-		assert(nwos_file_is_identical(&ref, path, match));
-
-		if (remove_option == Shred_Before_Remove)
+		if (nwos_file_is_identical(&ref, path, match))
 		{
-		    shred(path);
-		    printf("shredded and ");
-		}
+		    if (remove_option == Shred_Before_Remove)
+		    {
+			shred(path);
+			printf("shredded and ");
+		    }
 
-		if (unlink(path) != 0)
+		    if (unlink(path) != 0)
+		    {
+			perror(path);
+			exit(1);
+		    }
+
+		    printf("removed\n");
+		}
+		else
 		{
-		    perror(path);
-		    exit(1);
+		    printf("WARNING: stored file does not match exactly, NOT removed\n");
 		}
-
-		printf("removed\n");
 	    }
 	    else if (nwos_file_has_backup(&ref))
 	    {
@@ -321,6 +335,7 @@ void process_file(const char* path, MatchCode match, Remove_Option remove_option
 	    else
 	    {
 		printf("no known backup, not removed\n");
+		result = false;
 	    }
 	}
 	else
@@ -331,11 +346,14 @@ void process_file(const char* path, MatchCode match, Remove_Option remove_option
     else
     {
 	printf("NOT found\n");
+	result = false;
     }
+
+    return result;
 }
 
 
-void process_directory(const char* path, MatchCode match, Remove_Option remove_option)
+bool process_directory(const char* path, MatchCode match, Remove_Option remove_option)
 {
     DIR* dp;
     struct dirent *dir_entry;
@@ -343,6 +361,7 @@ void process_directory(const char* path, MatchCode match, Remove_Option remove_o
     char full_path[PATH_MAX];
     int i;
     struct stat stat_struct;
+    bool result = true;
 
     dp = opendir(path);
     if (dp == NULL)
@@ -388,11 +407,11 @@ void process_directory(const char* path, MatchCode match, Remove_Option remove_o
 
 	    if (S_ISDIR(stat_struct.st_mode))
 	    {
-		process_directory(full_path, match, remove_option);
+		if (!process_directory(full_path, match, remove_option)) result = false;
 	    }
 	    else
 	    {
-		process_file(full_path, match, remove_option);
+		if (!process_file(full_path, match, remove_option)) result = false;
 	    }
 	}
 
@@ -416,6 +435,8 @@ void process_directory(const char* path, MatchCode match, Remove_Option remove_o
 	    perror(path);
 	}
     }
+
+    return result;
 }
 
 
@@ -429,6 +450,7 @@ int main(int argc, char* argv[])
     char* path = DEFAULT_FILE;
     char normalized_path[PATH_MAX];
     struct stat stat_struct;
+    bool result = true;
 
     printf("\n");
 
@@ -522,7 +544,7 @@ int main(int argc, char* argv[])
 	{
 	    if (do_recursive)
 	    {
-		process_directory(".", match, remove_option);
+		if (!process_directory(".", match, remove_option)) result = false;
 	    }
 	    else
 	    {
@@ -555,23 +577,23 @@ int main(int argc, char* argv[])
 
 		if (S_ISDIR(stat_struct.st_mode))
 		{
-		    process_directory(normalized_path, match, remove_option);
+		    if (!process_directory(normalized_path, match, remove_option)) result = false;
 		}
 		else
 		{
-		    process_file(normalized_path, match, remove_option);
+		    if (!process_file(normalized_path, match, remove_option)) result = false;
 		}
 	    }
 	    else
 	    {
-		process_file(normalized_path, match, remove_option);
+		if (!process_file(normalized_path, match, remove_option)) result = false;
 	    }
 	}
     }
 
     nwos_terminate_objectify();
 
-    return 0;
+    return !result;    /* return 0 means success */
 }
 
 
